1.1.1 (2020-04-07)
------------------

- Fixed bug in shape of Cvd output after preparation of models.

1.1.0 (2020-04-05)
------------------

- Included tools to facilitate use of CvD models.
- Included option to broad CvD models to a given velocity dispersion.
- New routine to calculate wavelength dispersion with fixed velocity scale.

1.0 (2020-03-11)
------------------

- Initial release of the paintbox code.